@@ -241,13 +241,26 @@ class Config:
     def expand_path(self, path):
         return os.path.normpath(os.path.join(self.dir, os.path.expanduser(path)))
 
-    def get_socket(config):
-        if config.autostart:
-            return config.expand_path(f".s.PGSQL.{config.port}")
+    def get_socket(self):
+        if self.autostart:
+            return self.expand_path(f".s.PGSQL.{self.port}")
 
     def get_uri(config, driver=None):
         return f"postgresql{'+'+driver if driver else ''}://{config.user}:{config.password}@localhost:{config.port}/{config.database}"
 
+    def get_env(self):
+        env = dict(
+            PGHOST = self.host,
+            PGPORT = self.port,
+            PGSOCKET = self.socket,
+            PGDATABASE = self.database,
+            PGUSER = self.user,
+            PGPASSWORD = self.password,
+            PGURI = self.uri,
+        )
+        for k,v in env.items():
+            env[k] = '' if v==None else str(v)
+        return env
 
 
 def _run_server(daemon_fd, log_fd, config):
